fcnet
0.4.1
All Items
Crate Items
Structs
Enums
Crate
fcnet
source
Structs

Firecracker
Network
A configuration for a Firecracker microVM network.
Enums

Firecracker
Network
Error
An error that can be emitted by a Firecracker network operation.
Firecracker
Network
Operation
An operation that can be made with a FirecrackerNetwork.
Firecracker
Network
Type
The type of Firecracker network to work with.